function [d, idx, val] = dist(blk)
% Izracunavanje i sortiranje kumulativnih udaljenosti
% [d, idx, val] = dist(blk)
% 
% blk - ulazni blok 
% d   - sortirani vektor kumulativnih udaljenosti
% idx - indeksni vektor koji uspostavlja R-uredjenje niza val
% val - vrijednosti kolor-vektora iz ulaznog bloka preuredjene u vektor

[m, n, p] = size(blk);
val = reshape(blk, [m*n, 1, p]);
a = repmat(val, [1, m*n, 1]);
for r = 1:p
    b(:, :, r) = a(:, :, r)';
end
if p == 3
    d = sqrt(sum((b - a).^2, 3));
else
    d = abs(b - a);
end
[d, idx] = sort(sum(d));
